==> generator-gulp-angular-0.12.0.tgz: package/app/templates/gulp/_watch.js <==
'use strict';

var path = require('path');
var gulp = require('gulp');
var conf = require('./conf');

var browserSync = require('browser-sync');

function isOnlyChange(event) {
  return event.type === 'changed';
}

gulp.task('watch', [<%- watchTaskDeps.join(', ') %>], function () {

  gulp.watch([path.join(conf.paths.src, '/*.html'), 'bower.json'], ['inject']);

<% if (props.cssPreprocessor.extension === 'css') { -%>
  gulp.watch(path.join(conf.paths.src, '/app/**/*.css'), function(event) {
<% } else { -%>
  gulp.watch([
    path.join(conf.paths.src, '/app/**/*.css'),
    path.join(conf.paths.src, '/app/**/*.<%- props.cssPreprocessor.extension %>')
  ], function(event) {
<% } -%>
    if(isOnlyChange(event)) {
<% if (props.cssPreprocessor.key === 'none') { -%>
      browserSync.reload(event.path);
<% } else { -%>
      gulp.start('styles');
<% } -%>
    } else {
      gulp.start('inject');
    }
  });

<% if (props.jsPreprocessor.srcExtension !== 'es6') { -%>
<%   if (props.jsPreprocessor.extension === 'js') { -%>
  gulp.watch(path.join(conf.paths.src, '/app/**/*.js'), function(event) {
<%   } else { -%>
  gulp.watch([
    path.join(conf.paths.src, '/app/**/*.js'),
    path.join(conf.paths.src, '/app/**/*.<%- props.jsPreprocessor.extension %>')
  ], function(event) {
<%   } -%>
    if(isOnlyChange(event)) {
      gulp.start('scripts');
    } else {
      gulp.start('inject');
    }
  });
<% } -%>

<% if (props.htmlPreprocessor.key !== 'none') { -%>
  gulp.watch(path.join(conf.paths.src, '/app/**/*.<%- props.htmlPreprocessor.extension %>'), ['markups']);

<% } -%>
  gulp.watch(path.join(conf.paths.src, '/app/**/*.html'), function(event) {
    browserSync.reload(event.path);
  });
});

==> generator-gulp-angular-1.0.0-rc2.tgz: package/app/templates/gulp/_watch.js <==
'use strict';

var path = require('path');
var gulp = require('gulp');
var conf = require('./conf');

var browserSync = require('browser-sync');

function isOnlyChange(event) {
  return event.type === 'changed';
}

gulp.task('watch', [<%- watchTaskDeps.join(', ') %>], function () {

  gulp.watch([path.join(conf.paths.src, '/*.html'), 'bower.json'], ['inject']);

<% if (props.cssPreprocessor.extension === 'css') { -%>
  gulp.watch(path.join(conf.paths.src, '/app/**/*.css'), function(event) {
<% } else { -%>
  gulp.watch([
    path.join(conf.paths.src, '/app/**/*.css'),
    path.join(conf.paths.src, '/app/**/*.<%- props.cssPreprocessor.extension %>')
  ], function(event) {
<% } -%>
    if(isOnlyChange(event)) {
<% if (props.cssPreprocessor.key === 'noCssPrepro') { -%>
      browserSync.reload(event.path);
<% } else { -%>
      gulp.start('styles');
<% } -%>
    } else {
      gulp.start('inject');
    }
  });

<% if (props.jsPreprocessor.srcExtension !== 'es6' && props.jsPreprocessor.srcExtension !== 'ts') { -%>
<%   if (props.jsPreprocessor.extension === 'js') { -%>
  gulp.watch(path.join(conf.paths.src, '/app/**/*.js'), function(event) {
<%   } else { -%>
  gulp.watch([
    path.join(conf.paths.src, '/app/**/*.js'),
    path.join(conf.paths.src, '/app/**/*.<%- props.jsPreprocessor.extension %>')
  ], function(event) {
<%   } -%>
    if(isOnlyChange(event)) {
      gulp.start('scripts');
    } else {
      gulp.start('inject');
    }
  });
<% } -%>

<% if (props.htmlPreprocessor.key !== 'noHtmlPrepro') { -%>
  gulp.watch(path.join(conf.paths.src, '/app/**/*.<%- props.htmlPreprocessor.extension %>'), ['markups']);

<% } -%>
  gulp.watch(path.join(conf.paths.src, '/app/**/*.html'), function(event) {
    browserSync.reload(event.path);
  });
});
